/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.blur.console;

import org.apache.blur.console.util.Config;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.junit.AfterClass;
import org.junit.BeforeClass;

import java.io.File;
import java.io.IOException;

public class ConsoleTestBase {
  protected static String TABLE_PATH = new File("./target/tmp/test-data/test-tables").getAbsolutePath();
  private static boolean _managing;
  private static Log log = LogFactory.getLog(ConsoleTestBase.class);

  @BeforeClass
  public static void startup() throws IOException {
    if (!Config.isClusterSetup()) {
      Config.setupMiniCluster();
      _managing = true;
    }
    File file = new File("test-data");
    if (file.exists()) {
      rmr(file);
    }
  }

  private static void rmr(File file) {
    if (!file.exists()) {
      return;
    }
    if (file.isDirectory()) {
      for (File f : file.listFiles()) {
        rmr(f);
      }
    }
    file.delete();
  }

  @AfterClass
  public static void shutdown() throws IOException {
    if (_managing) {
      log.warn("SHUTTING DOWN MINI CLUSTER");
      Config.shutdownMiniCluster();
    }
  }

  protected void setupConfigIfNeeded() throws Exception {
    if (Config.getBlurConfig() == null) {
      System.setProperty("blur.console.refreshtime", "0");
      Config.setupConfig();
    }
  }
}
